# CoreX ai_audio - deepspeech

This package provides an implementation of the CoreX ai_audio interface for deepspeech.

## Installation
~~~bash
pip install corex-ai_audio-deepspeech
~~~

## Usage
~~~python
from corex_ai_audio_deepspeech.handler import DeepspeechHandler
handler = DeepspeechHandler()
handler.example_method()
~~~

## License
This package is licensed under the MIT License. See [LICENSE](../LICENSE) for details.
